@@ -1,5 +1,11 @@
-/* SPDX-License-Identifier: LGPL-2.1-only */
 /*
+ * lib/route/cls/ematch/meta.c		Metadata Match
+ *
+ *	This library is free software; you can redistribute it and/or
+ *	modify it under the terms of the GNU Lesser General Public
+ *	License as published by the Free Software Foundation version 2.1
+ *	of the License.
+ *
  * Copyright (c) 2010-2013 Thomas Graf <tgraf@suug.ch>
  */
 
@@ -10,15 +16,12 @@
  * @{
  */
 
-#include "nl-default.h"
-
-#include <linux/tc_ematch/tc_em_meta.h>
-
+#include <netlink-private/netlink.h>
+#include <netlink-private/tc.h>
 #include <netlink/netlink.h>
 #include <netlink/route/cls/ematch.h>
 #include <netlink/route/cls/ematch/meta.h>
-
-#include "nl-priv-dynamic-core/nl-core.h"
+#include <linux/tc_ematch/tc_em_meta.h>
 
 struct rtnl_meta_value
 {
@@ -196,7 +199,7 @@ static const struct trans_tbl meta_int[] = {
 	__ADD(TCF_META_ID_SK_ERR_QLEN, sk_err_qlen),
 	__ADD(TCF_META_ID_SK_FORWARD_ALLOCS, sk_forward_allocs),
 	__ADD(TCF_META_ID_SK_ALLOCS, sk_allocs),
-	__ADD(__TCF_META_ID_SK_ROUTE_CAPS, sk_route_caps),
+	__ADD(TCF_META_ID_SK_ROUTE_CAPS, sk_route_caps),
 	__ADD(TCF_META_ID_SK_HASH, sk_hash),
 	__ADD(TCF_META_ID_SK_LINGERTIME, sk_lingertime),
 	__ADD(TCF_META_ID_SK_ACK_BACKLOG, sk_ack_backlog),
@@ -243,9 +246,9 @@ static void dump_value(struct rtnl_meta_value *v, struct nl_dump_params *p)
 					nl_dump(p, " >> %u", v->mv_shift);
 
 				if (v->mv_len == 4)
-					nl_dump(p, " & %#lx", (long unsigned) *(uint32_t *) (v + 1));
+					nl_dump(p, " & %#x", *(uint32_t *) (v + 1));
 				else if (v->mv_len == 8)
-					nl_dump(p, " & %#llx", (long long unsigned) (*(uint64_t *) (v + 1)));
+					nl_dump(p, " & %#x", *(uint64_t *) (v + 1));
 			}
 		break;
 
@@ -325,7 +328,7 @@ static struct rtnl_ematch_ops meta_ops = {
 	.eo_free	= meta_free,
 };
 
-static void _nl_init meta_init(void)
+static void __init meta_init(void)
 {
 	rtnl_ematch_register(&meta_ops);
 }
